@@ -565,6 +565,9 @@ bftextview2_run_spellcheck(BluefishTextView * btv)
 void
 bftextview2_spell_init(void)
 {
+#ifdef WIN32
+	g_setenv("ENCHANT_DICT_DIR", "./share/enchant/", TRUE);
+#endif
 	eb = enchant_broker_init();
 	if (!eb) {
 		g_warning("could not initialize spell checking engine\n");
