@@ -2,7 +2,7 @@
  * bluefish.c - the main function
  *
  * Copyright (C) 1998 Olivier Sessink and Chris Mazuc
- * Copyright (C) 1999-2011 Olivier Sessink
+ * Copyright (C) 1999-2025 Olivier Sessink
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -204,12 +204,16 @@ static gboolean startup_in_idle(gpointer data) {
 			}
 			if (startup->firstbfwin->session == main_v->session)
 				bmark_reload(startup->firstbfwin); /* do not reload bookmarks for a project */
-			/* set GTK settings, must be AFTER the menu is created */
-			{
+#if GTK_CHECK_VERSION(3,0,0)
+			/* nothing at startup for gtk3 */
+#else
+			if (main_v->props.dynamic_menu_shortcut){
+				/* set GTK settings, must be AFTER the menu is created */
 				GtkSettings *gtksettings = gtk_settings_get_default();
 				g_object_set(G_OBJECT(gtksettings), "gtk-can-change-accels", TRUE, NULL);
-				rcfile_load_accelerators(FALSE);
 			}
+#endif
+			rcfile_load_accelerators(FALSE);
 			autosave_init(TRUE, startup->firstbfwin);
 		#ifdef WITH_MSG_QUEUE
 			if (main_v->props.open_in_running_bluefish) {
