@@ -307,7 +307,7 @@ scroll_to_lstore_path_idle_lcb(gpointer data)
 }
 
 static void
-list_store_set_markup_escaped(GtkListStore *store, GtkTreeIter *iter, gint column, gchar *text)
+list_store_set_markup_escaped(GtkListStore *store, GtkTreeIter *iter, gint column, const gchar *text)
 {
 	gchar *tmp = g_markup_escape_text(text,-1);
 	gtk_list_store_set(GTK_LIST_STORE(store), iter, column, tmp, -1);
@@ -355,7 +355,7 @@ void outputbox_add_line(Tbfwin *bfwin, const gchar *uri, gint line, const gchar
 }
 
 void
-fill_output_box(gpointer data, gchar * string)
+fill_output_box(gpointer data, const gchar * string)
 {
 	GtkTreeIter iter;
 	/*int ovector[30]; */
